function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

function getScrollPercent() {
  var h = document.documentElement;
  var b = document.body;
  return (h.scrollTop || b.scrollTop) / ((h.scrollHeight || b.scrollHeight) - h.clientHeight) * 100;
}

var fadeScrollAnimation = function fadeScrollAnimation(_ref) {
  var elementRef = _ref.elementRef,
      startAndEnd = _ref.startAndEnd;
  var start = startAndEnd[0],
      end = startAndEnd[1];
  window.addEventListener('scroll', function () {
    window.requestAnimationFrame(function () {
      var scrollPercent = getScrollPercent();

      if (scrollPercent < start) {
        elementRef.style.opacity = '1';
        elementRef.style.visibility = 'visible';
      } else if (scrollPercent > end) {
        elementRef.style.opacity = '0';
        elementRef.style.visibility = 'hidden';
      } else {
        var elementRealScrolled = scrollPercent - start;
        var elementScrolledPercent = elementRealScrolled / (end - start);
        elementRef.style.opacity = "" + (1 - elementScrolledPercent);
        elementRef.style.visibility = 'visible';
      }
    });
  });
};

var Fade = function Fade(_ref2) {
  var children = _ref2.children,
      startAndEnd = _ref2.startAndEnd;
  var wrapperRef = React.useRef(null);
  React.useEffect(function () {
    if (wrapperRef.current) {
      fadeScrollAnimation({
        elementRef: wrapperRef.current,
        startAndEnd: startAndEnd
      });
    }
  }, []);
  return React__default.createElement("div", {
    ref: wrapperRef,
    style: {
      width: '100vw',
      height: '100vh',
      position: 'fixed'
    }
  }, children);
};

var showAnimation = function showAnimation(_ref) {
  var elementRef = _ref.elementRef,
      startAndEnd = _ref.startAndEnd;
  var start = startAndEnd[0],
      end = startAndEnd[1];
  window.addEventListener('scroll', function () {
    window.requestAnimationFrame(function () {
      var scrollPercent = getScrollPercent();

      if (scrollPercent <= start) {
        elementRef.style.opacity = '0';
      } else if (scrollPercent > end) {
        elementRef.style.opacity = '1';
      } else {
        var elementRealScrolled = scrollPercent - start;
        var elementScrolledPercent = elementRealScrolled / (end - start);
        elementRef.style.opacity = "" + elementScrolledPercent;
      }
    });
  });
};

var Show = function Show(_ref2) {
  var children = _ref2.children,
      startAndEnd = _ref2.startAndEnd;
  var wrapperRef = React.useRef(null);
  React.useEffect(function () {
    if (wrapperRef.current) {
      showAnimation({
        elementRef: wrapperRef.current,
        startAndEnd: startAndEnd
      });
    }
  }, []);
  return React__default.createElement("div", {
    ref: wrapperRef,
    style: {
      width: '100vw',
      height: '100vh',
      position: 'fixed',
      opacity: 0
    }
  }, children);
};

var translateXAnimation = function translateXAnimation(_ref) {
  var elementRef = _ref.elementRef,
      x = _ref.x,
      startAndEnd = _ref.startAndEnd;
  var start = startAndEnd[0],
      end = startAndEnd[1];
  window.addEventListener('scroll', function () {
    window.requestAnimationFrame(function () {
      var scrollPercent = getScrollPercent();

      if (scrollPercent <= start) {
        elementRef.style.transform = 'translateX(0%) ';
      } else if (scrollPercent > end) {
        elementRef.style.transform = "translateX(" + x + "%) ";
      } else {
        var elementRealScrolled = scrollPercent - start;
        var elementScrolledPercent = elementRealScrolled / (end - start);
        elementRef.style.transform = "translateX(" + x * elementScrolledPercent + "%) ";
      }
    });
  });
};

var TranslateX = function TranslateX(_ref2) {
  var children = _ref2.children,
      startAndEnd = _ref2.startAndEnd,
      x = _ref2.x;
  var wrapperRef = React.useRef(null);
  React.useEffect(function () {
    if (wrapperRef.current) {
      translateXAnimation({
        elementRef: wrapperRef.current,
        x: x,
        startAndEnd: startAndEnd
      });
    }
  }, []);
  return React__default.createElement("div", {
    ref: wrapperRef,
    style: {
      width: 'auto',
      height: 'auto',
      position: 'fixed'
    }
  }, children);
};

var translateYAnimation = function translateYAnimation(_ref) {
  var elementRef = _ref.elementRef,
      y = _ref.y,
      startAndEnd = _ref.startAndEnd;
  var start = startAndEnd[0],
      end = startAndEnd[1];
  window.addEventListener('scroll', function () {
    window.requestAnimationFrame(function () {
      var scrollPercent = getScrollPercent();

      if (scrollPercent <= start) {
        elementRef.style.transform = 'translateY(0%) ';
      } else if (scrollPercent > end) {
        elementRef.style.transform = "translateY(" + y + "%) ";
      } else {
        var elementRealScrolled = scrollPercent - start;
        var elementScrolledPercent = elementRealScrolled / (end - start);
        elementRef.style.transform = "translateY(" + y * elementScrolledPercent + "%) ";
      }
    });
  });
};

var TranslateY = function TranslateY(_ref2) {
  var children = _ref2.children,
      startAndEnd = _ref2.startAndEnd,
      y = _ref2.y;
  var wrapperRef = React.useRef(null);
  React.useEffect(function () {
    if (wrapperRef.current) {
      translateYAnimation({
        elementRef: wrapperRef.current,
        y: y,
        startAndEnd: startAndEnd
      });
    }
  }, []);
  return React__default.createElement("div", {
    ref: wrapperRef,
    style: {
      width: 'auto',
      height: 'auto',
      position: 'fixed'
    }
  }, children);
};

var useScrollPercent = function useScrollPercent() {
  var _useState = React.useState(0),
      scrollPercent = _useState[0],
      setScrollPercent = _useState[1];

  var eventFunction = function eventFunction() {
    var percent = getScrollPercent();
    setScrollPercent(percent);
  };

  React.useEffect(function () {
    window.addEventListener('scroll', eventFunction);
    return function () {
      window.removeEventListener('scroll', eventFunction);
    };
  });
  return scrollPercent;
};

exports.Fade = Fade;
exports.Show = Show;
exports.TranslateX = TranslateX;
exports.TranslateY = TranslateY;
exports.useScrollPercent = useScrollPercent;
//# sourceMappingURL=index.js.map
